@@ -115,7 +115,7 @@ class ProvenanceHashMap:
 
 def hash_file(f):
     h = hashlib.sha256()
-    with open(f, "b") as f:
+    with open(f, "rb") as f:
         # Read and update hash string value in blocks of 4K
         for byte_block in iter(lambda: f.read(4096), b""):
             h.update(byte_block)
