@@ -44,7 +44,7 @@ class Batch:
 
     def get_batch(self, items: list):
         """Return the defined batch of the given items.
-           Items are usually input files."""
+        Items are usually input files."""
         # make sure that we always consider items in the same order
         if len(items) < self.batches:
             raise WorkflowError(
@@ -207,7 +207,7 @@ class DAG:
             except ValueError:
                 # commonpath raises error if windows drives are different.
                 continue
-            if common == os.path.commonpath([a]) and job_a != job_b:
+            if a != b and common == os.path.commonpath([a]) and job_a != job_b:
                 raise ChildIOException(parent=outputs[i], child=outputs[i + 1])
 
     @property
@@ -530,8 +530,8 @@ class DAG:
         shutil.rmtree(job.shadow_dir)
 
     def check_periodic_wildcards(self, job):
-        """ Raise an exception if a wildcard of the given job appears to be periodic,
-        indicating a cyclic dependency. """
+        """Raise an exception if a wildcard of the given job appears to be periodic,
+        indicating a cyclic dependency."""
         for wildcard, value in job.wildcards_dict.items():
             periodic_substring = self.periodic_wildcard_detector.is_periodic(value)
             if periodic_substring is not None:
@@ -1044,7 +1044,7 @@ class DAG:
         self._group = groups
 
     def update_ready(self, jobs=None):
-        """ Update information whether a job is ready to execute.
+        """Update information whether a job is ready to execute.
 
         Given jobs must be needrun jobs!
         """
@@ -1100,7 +1100,7 @@ class DAG:
 
     def handle_pipes(self):
         """Use pipes to determine job groups. Check if every pipe has exactly
-           one consumer"""
+        one consumer"""
         for job in self.needrun_jobs:
             candidate_groups = set()
             if job.group is not None:
@@ -1908,8 +1908,7 @@ class DAG:
             raise e
 
     def clean(self, only_temp=False, dryrun=False):
-        """Removes files generated by the workflow.
-        """
+        """Removes files generated by the workflow."""
         for job in self.jobs:
             for f in job.output:
                 if not only_temp or is_flagged(f, "temp"):
@@ -1926,8 +1925,7 @@ class DAG:
                                 f.remove(remove_non_empty_dir=only_temp)
 
     def list_untracked(self):
-        """List files in the workdir that are not in the dag.
-        """
+        """List files in the workdir that are not in the dag."""
         used_files = set()
         files_in_cwd = set()
         for job in self.jobs:
