@@ -71,6 +71,7 @@ class Env:
         self._archive_file = None
         self._container_img = container_img
         self._cleanup = cleanup
+        self._singularity_args = dag.workflow.singularity_args
 
     @property
     def container_img_url(self):
@@ -274,13 +275,20 @@ class Env:
 
                     # install packages manually from env archive
                     cmd = " ".join(
-                        ["conda", "create", "--copy", "--prefix '{}'".format(env_path)]
+                        [
+                            "conda",
+                            "create",
+                            "--quiet",
+                            "--copy",
+                            "--prefix '{}'".format(env_path),
+                        ]
                         + packages
                     )
                     if self._container_img:
                         cmd = singularity.shellcmd(
                             self._container_img.path,
                             cmd,
+                            args=self._singularity_args,
                             envvars=self.get_singularity_envvars(),
                         )
                     out = shell.check_output(
@@ -301,6 +309,7 @@ class Env:
                             self.frontend,
                             "env",
                             "create",
+                            "--quiet",
                             "--file '{}'".format(target_env_file),
                             "--prefix '{}'".format(env_path),
                         ]
@@ -309,6 +318,7 @@ class Env:
                         cmd = singularity.shellcmd(
                             self._container_img.path,
                             cmd,
+                            args=self._singularity_args,
                             envvars=self.get_singularity_envvars(),
                         )
                     out = shell.check_output(
