@@ -32,8 +32,8 @@ GoogleLifeSciencesJob = namedtuple(
 
 class GoogleLifeSciencesExecutor(ClusterExecutor):
     """the GoogleLifeSciences executor uses Google Cloud Storage, and
-       Compute Engine paired with the Google Life Sciences API.
-       https://cloud.google.com/life-sciences/docs/quickstart
+    Compute Engine paired with the Google Life Sciences API.
+    https://cloud.google.com/life-sciences/docs/quickstart
     """
 
     def __init__(
@@ -54,6 +54,8 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         restart_times=None,
         exec_job=None,
         max_status_checks_per_second=1,
+        preemption_default=None,
+        preemptible_rules=None,
     ):
 
         # Attach variables for easy access
@@ -77,6 +79,9 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
             "--notemp --no-hooks --nolock " % self.snakefile
         )
 
+        # Set preemptible instances
+        self._set_preemptible_rules(preemption_default, preemptible_rules)
+
         # IMPORTANT: using Compute Engine API and not k8s == no support secrets
         self.envvars = list(self.workflow.envvars) or []
 
@@ -129,8 +134,8 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _get_services(self):
         """use the Google Discovery Build to generate API clients
-           for Life Sciences, and use the google storage python client 
-           for storage.
+        for Life Sciences, and use the google storage python client
+        for storage.
         """
         from googleapiclient.discovery import build as discovery_build
         from oauth2client.client import (
@@ -160,11 +165,11 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _get_bucket(self):
         """get a connection to the storage bucket (self.bucket) and exit
-           if the name is taken or otherwise invalid.
+        if the name is taken or otherwise invalid.
 
-           Parameters
-           ==========
-           workflow: the workflow object to derive the prefix from
+        Parameters
+        ==========
+        workflow: the workflow object to derive the prefix from
         """
         import google
 
@@ -173,6 +178,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         self.gs_subdir = re.sub(
             "^{}/".format(bucket_name), "", self.workflow.default_remote_prefix
         )
+        self.gs_logs = os.path.join(self.gs_subdir, "google-lifesciences-logs")
 
         # Case 1: The bucket already exists
         try:
@@ -194,17 +200,18 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
         logger.debug("bucket=%s" % self.bucket.name)
         logger.debug("subdir=%s" % self.gs_subdir)
+        logger.debug("logs=%s" % self.gs_logs)
 
     def _set_location(self, location=None):
         """The location is where the Google Life Sciences API is located.
-           This can be meaningful if the requester has data residency
-           requirements or multi-zone needs. To determine this value,
-           we first use the locations API to determine locations available,
-           and then compare them against:
+        This can be meaningful if the requester has data residency
+        requirements or multi-zone needs. To determine this value,
+        we first use the locations API to determine locations available,
+        and then compare them against:
 
-           1. user specified location or prefix
-           2. regions having the same prefix
-           3. if cannot be satisifed, we throw an error.
+        1. user specified location or prefix
+        2. regions having the same prefix
+        3. if cannot be satisifed, we throw an error.
         """
         # Derive available locations
         # See https://cloud.google.com/life-sciences/docs/concepts/locations
@@ -264,7 +271,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def shutdown(self):
         """shutdown deletes build packages if the user didn't request to clean
-           up the cache. At this point we've already cancelled running jobs.
+        up the cache. At this point we've already cancelled running jobs.
         """
         # Delete build source packages only if user regooglquested no cache
         if self._save_storage_cache:
@@ -281,7 +288,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def cancel(self):
         """cancel execution, usually by way of control+c. Cleanup is done in
-           shutdown (deleting cached workdirs in Google Cloud Storage
+        shutdown (deleting cached workdirs in Google Cloud Storage
         """
         import googleapiclient
 
@@ -300,7 +307,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def get_available_machine_types(self):
         """Using the regions available at self.regions, use the GCP API
-           to retrieve a lookup dictionary of all available machine types.
+        to retrieve a lookup dictionary of all available machine types.
         """
         # Regular expression to determine if zone in region
         regexp = "^(%s)" % "|".join(self.regions)
@@ -340,9 +347,9 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _add_gpu(self, gpu_count):
         """Add a number of NVIDIA gpus to the current executor. This works
-           by way of adding nvidia_gpu to the job default resources, and also
-           changing the default machine type prefix to be n1, which is
-           the currently only supported instance type for using GPUs for LHS.
+        by way of adding nvidia_gpu to the job default resources, and also
+        changing the default machine type prefix to be n1, which is
+        the currently only supported instance type for using GPUs for LHS.
         """
         if not gpu_count or gpu_count == 0:
             return
@@ -357,9 +364,34 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         if not self._machine_type_prefix.startswith("n1"):
             self._machine_type_prefix = "n1"
 
+    def _set_preemptible_rules(self, preemption_default=None, preemptible_rules=None):
+        """define a lookup dictionary for preemptible instance retries, which
+        is supported by the Google Life Science API. The user can set a default
+        for all steps, specify per step, or define a default for all steps
+        that aren't individually customized.
+        """
+        self.preemptible_rules = {}
+
+        # If a default is defined, we apply it to all the rules
+        if preemption_default is not None:
+            self.preemptible_rules = {
+                rule.name: preemption_default for rule in self.workflow.rules
+            }
+
+        # Now update custom set rules
+        if preemptible_rules is not None:
+            for rule in preemptible_rules:
+                rule_name, restart_times = rule.strip().split("=")
+                self.preemptible_rules[rule_name] = int(restart_times)
+
+        # Ensure we set the number of restart times for each rule
+        for rule_name, restart_times in self.preemptible_rules.items():
+            rule = self.workflow.get_rule(rule_name)
+            rule.restart_times = restart_times
+
     def _generate_job_resources(self, job):
         """given a particular job, generate the resources that it needs,
-           including default regions and the virtual machine configuration
+        including default regions and the virtual machine configuration
         """
         # Right now, do a best effort mapping of resources to instance types
         cores = job.resources.get("_cores", 1)
@@ -469,10 +501,12 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         logger.debug(
             "Selected machine type {}:{}".format(smallest, selected["description"])
         )
+
         virtual_machine = {
             "machineType": smallest,
             "labels": {"app": "snakemake"},
             "bootDiskSizeGb": disk_gb,
+            "preemptible": job.rule.name in self.preemptible_rules,
         }
 
         # If the user wants gpus, add accelerators here
@@ -489,10 +523,10 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _get_accelerator(self, gpu_count, zone, gpu_model=None):
         """Get an appropriate accelerator for a GPU given a zone selection.
-           Currently Google offers NVIDIA Tesla T4 (likely the best),
-           NVIDIA P100, and the same T4 for a graphical workstation. Since
-           this isn't a graphical workstation use case, we choose the 
-           accelerator that has >= to the maximumCardsPerInstace
+        Currently Google offers NVIDIA Tesla T4 (likely the best),
+        NVIDIA P100, and the same T4 for a graphical workstation. Since
+        this isn't a graphical workstation use case, we choose the
+        accelerator that has >= to the maximumCardsPerInstace
         """
         if not gpu_count or gpu_count == 0:
             return
@@ -542,9 +576,9 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _set_snakefile(self):
         """The snakefile must be a relative path, which cannot be reliably
-           derived from the self.workflow.snakefile as we might have moved
-           execution into a temporary directory, and the initial Snakefile
-           was somewhere else on the system.
+        derived from the self.workflow.snakefile as we might have moved
+        execution into a temporary directory, and the initial Snakefile
+        was somewhere else on the system.
         """
         from snakemake import SNAKEFILE_CHOICES
 
@@ -555,7 +589,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _set_workflow_sources(self):
         """We only add files from the working directory that are config related
-           (e.g., the Snakefile or a config.yml equivalent), or checked into git. 
+        (e.g., the Snakefile or a config.yml equivalent), or checked into git.
         """
         self.workflow_sources = []
 
@@ -575,8 +609,8 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _generate_build_source_package(self):
         """in order for the instance to access the working directory in storage,
-           we need to upload it. This file is cleaned up at the end of the run.
-           We do this, and then obtain from the instance and extract.
+        we need to upload it. This file is cleaned up at the end of the run.
+        We do this, and then obtain from the instance and extract.
         """
         # Workflow sources for cloud executor must all be under same workdir root
         for filename in self.workflow_sources:
@@ -622,7 +656,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _upload_build_source_package(self, targz):
         """given a .tar.gz created for a workflow, upload it to source/cache
-           of Google storage, only if the blob doesn't already exist.
+        of Google storage, only if the blob doesn't already exist.
         """
         # Upload to temporary storage, only if doesn't exist
         self.pipeline_package = "source/cache/%s" % os.path.basename(targz)
@@ -631,9 +665,31 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         if not blob.exists():
             blob.upload_from_filename(targz, content_type="application/gzip")
 
+    def _generate_log_action(self, job):
+        """generate an action to save the pipeline logs to storage."""
+        # script should be changed to this when added to version control!
+        # https://raw.githubusercontent.com/snakemake/snakemake/master/snakemake/executors/google_lifesciences_helper.py
+
+        # Save logs from /google/logs/output to source/logs in bucket
+        commands = [
+            "/bin/bash",
+            "-c",
+            "wget -O /gls.py https://gist.githubusercontent.com/vsoch/f5a6a6d1894be1e67aa4156c5b40c8e9/raw/a4e9ddbeba20996ca62745fcd4d9ecd7bfa3b311/gls.py && chmod +x /gls.py && source activate snakemake || true && python /gls.py save %s /google/logs %s/%s"
+            % (self.bucket.name, self.gs_logs, job.name),
+        ]
+
+        # Always run the action to generate log output
+        action = {
+            "containerName": "snakelog-{}-{}".format(job.name, job.jobid),
+            "imageUri": self.container_image,
+            "commands": commands,
+            "labels": self._generate_pipeline_labels(job),
+            "alwaysRun": True,
+        }
+        return action
+
     def _generate_job_action(self, job):
-        """generate a single action to execute the job.
-        """
+        """generate a single action to execute the job."""
         # Derive the entrypoint command, the same content that might be written by self.get_jobscript(job)
         use_threads = "--force-use-threads" if not job.is_group() else ""
 
@@ -644,13 +700,15 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         # Now that we've parsed the job resource requirements, add to exec
         exec_job += self.get_default_resources_args()
 
+        # script should be changed to this when added to version control!
+        # https://raw.githubusercontent.com/snakemake/snakemake/master/snakemake/executors/google_lifesciences_helper.py
         # The full command to download the archive, extract, and run
         # For snakemake bases, we must activate the conda environment, but
         # for custom images we must allow this to fail (hence || true)
         commands = [
             "/bin/bash",
             "-c",
-            "mkdir -p /workdir && cd /workdir && wget -O /download.py https://gist.githubusercontent.com/vsoch/84886ef6469bedeeb9a79a4eb7aec0d1/raw/181499f8f17163dcb2f89822079938cbfbd258cc/download.py && chmod +x /download.py && source activate snakemake || true && python /download.py download %s %s /tmp/workdir.tar.gz && tar -xzvf /tmp/workdir.tar.gz && %s"
+            "mkdir -p /workdir && cd /workdir && wget -O /download.py https://gist.githubusercontent.com/vsoch/f5a6a6d1894be1e67aa4156c5b40c8e9/raw/a4e9ddbeba20996ca62745fcd4d9ecd7bfa3b311/gls.py && chmod +x /download.py && source activate snakemake || true && python /download.py download %s %s /tmp/workdir.tar.gz && tar -xzvf /tmp/workdir.tar.gz && %s"
             % (self.bucket.name, self.pipeline_package, exec_job),
         ]
 
@@ -670,8 +728,8 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
         return "snakejob-%s-%s-%s" % (self.run_namespace, job.name, job.jobid)
 
     def _generate_pipeline_labels(self, job):
-        """generate basic labels to identify the job, namespace, and that 
-           snakemake is running the show!
+        """generate basic labels to identify the job, namespace, and that
+        snakemake is running the show!
         """
         jobname = self._get_jobname(job)
         labels = {"name": jobname, "app": "snakemake"}
@@ -679,7 +737,7 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _generate_environment(self):
         """loop through envvars (keys to host environment) and add
-           any that are requested for the container environment.
+        any that are requested for the container environment.
         """
         envvars = {}
         for key in self.envvars:
@@ -695,16 +753,17 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _generate_pipeline(self, job):
         """based on the job details, generate a google Pipeline object
-           to pass to pipelines.run. This includes actions, resources,
-           environment, and timeout.
+        to pass to pipelines.run. This includes actions, resources,
+        environment, and timeout.
         """
-        # Generate actions (one per job) and resources
+        # Generate actions (one per job step) and log saving action (runs no matter what) and resources
         resources = self._generate_job_resources(job)
         action = self._generate_job_action(job)
+        log_action = self._generate_log_action(job)
 
         pipeline = {
             # Ordered list of actions to execute
-            "actions": [action],
+            "actions": [action, log_action],
             # resources required for execution
             "resources": resources,
             # Technical question - difference between resource and action environment
@@ -753,8 +812,13 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
             "Get status with:\n"
             "gcloud config set project {project}\n"
             "gcloud beta lifesciences operations describe {location}/operations/{jobid}\n"
-            "gcloud beta lifesciences operations list".format(
-                project=self.project, jobid=jobid, location=self.location
+            "gcloud beta lifesciences operations list\n"
+            "Logs will be saved to: {bucket}/{logdir}\n".format(
+                project=self.project,
+                jobid=jobid,
+                location=self.location,
+                bucket=self.bucket.name,
+                logdir=self.gs_logs,
             )
         )
 
@@ -764,9 +828,9 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _job_was_successful(self, status):
         """based on a status response (a [pipeline].projects.locations.operations.get
-           debug print the list of events, return True if all return codes 0
-           and False otherwise (indication of failure). In that a nonzero exit
-           status is found, we also debug print it for the user.
+        debug print the list of events, return True if all return codes 0
+        and False otherwise (indication of failure). In that a nonzero exit
+        status is found, we also debug print it for the user.
         """
         success = True
 
@@ -797,14 +861,14 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _retry_request(self, request, timeout=2, attempts=3):
         """The Google Python API client frequently has BrokenPipe errors. This
-           function takes a request, and executes it up to number of retry,
-           each time with a 2* increase in timeout.
+        function takes a request, and executes it up to number of retry,
+        each time with a 2* increase in timeout.
 
-           Parameters
-           ==========
-           request: the Google Cloud request that needs to be executed
-           timeout: time to sleep (in seconds) before trying again
-           attempts: remaining attempts, throw error when hit 0
+        Parameters
+        ==========
+        request: the Google Cloud request that needs to be executed
+        timeout: time to sleep (in seconds) before trying again
+        attempts: remaining attempts, throw error when hit 0
         """
         import googleapiclient
 
@@ -824,8 +888,8 @@ class GoogleLifeSciencesExecutor(ClusterExecutor):
 
     def _wait_for_jobs(self):
         """wait for jobs to complete. This means requesting their status,
-           and then marking them as finished when a "done" parameter
-           shows up. Even for finished jobs, the status should still return
+        and then marking them as finished when a "done" parameter
+        shows up. Even for finished jobs, the status should still return
         """
         import googleapiclient
 
