@@ -58,8 +58,8 @@ class Persistence:
         else:
             self.shadow_path = os.path.join(shadow_prefix, "shadow")
 
-        # place to store any auxilliary information needed during a run (e.g. source tarballs)
-        self.aux_path = os.path.join(self.path, "aux")
+        # place to store any auxiliary information needed during a run (e.g. source tarballs)
+        self.aux_path = os.path.join(self.path, "auxiliary")
 
         for d in (
             self._metadata_path,
