@@ -88,8 +88,7 @@ class RemoteProvider(AbstractRemoteProvider):
 
 
 class RemoteObject(AbstractRemoteObject):
-    """ This is a class to interact with an iRODS server.
-    """
+    """This is a class to interact with an iRODS server."""
 
     def __init__(self, *args, keep_local=False, provider=None, **kwargs):
         super(RemoteObject, self).__init__(
@@ -159,8 +158,8 @@ class RemoteObject(AbstractRemoteObject):
             raise WorkflowError("File doesn't exist remotely: %s" % self.local_file())
 
     def is_newer(self, time):
-        """ Returns true of the file is newer than time, or if it is
-            a symlink that points to a file newer than time. """
+        """Returns true of the file is newer than time, or if it is
+        a symlink that points to a file newer than time."""
         return self.mtime() > time
 
     def size(self):
